import { DBReader } from "./src/dbreader";
import _ from "lodash";
import { PackDbFetcher } from "./src/packdbfetcher";
import axios from "axios";
import { readLFList } from "./src/utility";
import moment from "moment";

const DATE = process.env.DATE;

async function getBanlist() {
	const lflistReq = await axios.get<string>("https://cdn02.moecube.com:444/ygopro-database/zh-CN/lflist.conf", {
		responseType: 'document'
	});
	const lflists = (await readLFList(lflistReq.data)).filter(l => !l.name.includes('TCG')).map(l => ({
		...l,
		date: moment(l.name.split(' ')[0], 'YYYY.MM')
	})).filter(l => l.date.isBefore(DATE));
	return _.maxBy(lflists, l => l.date.unix());
}

async function main() {
	const dbreader = new DBReader({
		name: "Database",
		//level: Logger.DEBUG
	});
	await dbreader.init();
	const cards = await PackDbFetcher.fetchOnce(dbreader, `date <= '${DATE}'`);
	console.log(cards.length);
	
	await dbreader.run(cards, {
		extraBanlists: [await getBanlist()],
	});
	process.exit();
}
main();
